@@ -26,6 +26,7 @@
 #define AKREGATOR_ARTICLEVIEWER_H
 
 #include "article.h"
+#include "akregator_export.h"
 
 #include <khtml_part.h>
 
@@ -51,7 +52,7 @@ class TreeNode;
 
 class ArticleViewerPart;
 
-class ArticleViewer : public QFrame
+class AKREGATORPART_EXPORT ArticleViewer : public QWidget
 {
     Q_OBJECT
     public:
@@ -78,6 +79,8 @@ class ArticleViewer : public QFrame
          *  @param node The node to observe */
         void showNode(Akregator::TreeNode* node);
 
+        QSize sizeHint() const;
+
     public slots:
 
         void slotZoomIn(int);
