@@ -210,7 +210,11 @@ QVector<Feed*> Feed::feeds()
 
 Article Feed::findArticle(const QString& guid) const
 {
-    return d->articles[guid];
+  Article a;
+  if ( !d->articles.isEmpty() ) {
+    a = d->articles[guid];
+  }
+  return a;
 }
 
 QList<Article> Feed::articles()
@@ -641,6 +645,7 @@ void Feed::fetchCompleted(Syndication::Loader *l, Syndication::FeedPtr doc, Synd
             d->fetchErrorCode = status;
             emit fetchError(this);
         }
+        markAsFetchedNow();
         return;
     }
 
@@ -675,10 +680,16 @@ void Feed::fetchCompleted(Syndication::Loader *l, Syndication::FeedPtr doc, Synd
 
     appendArticles(doc);
 
-    d->archive->setLastFetch( QDateTime::currentDateTime().toTime_t());
+    markAsFetchedNow();
     emit fetched(this);
 }
 
+void Feed::markAsFetchedNow()
+{
+    if ( d->archive )
+    d->archive->setLastFetch( QDateTime::currentDateTime().toTime_t());
+}
+
 QIcon Feed::icon() const
 {
     if ( fetchErrorOccurred() )
