@@ -22,17 +22,17 @@
     without including the source code for Qt in the source distribution.
 */
 
+#include "notificationmanager.h"
+#include "feed.h"
+
 #include <klocale.h>
 #include <knotification.h>
-#include <k3staticdeleter.h>
 #include <kurl.h>
 #include <kglobal.h>
 
 #include <QTimer>
 #include <QList>
 
-#include "feed.h"
-#include "notificationmanager.h"
 
 namespace Akregator {
 
@@ -76,7 +76,7 @@ void NotificationManager::slotNotifyFeeds(const QStringList& feeds)
     if (feeds.count() == 1)
     {
         //KNotifyClient::Instance inst(m_instance);
-        KNotification::event("feed_added", i18n("Feed added:\n %1", feeds[0]), QPixmap() ,m_widget);
+        KNotification::event("FeedAdded", i18n("Feed added:\n %1", feeds[0]), QPixmap() ,m_widget, KNotification::CloseOnTimeout, m_instance);
     }
     else if (feeds.count() > 1)
     {
@@ -84,7 +84,7 @@ void NotificationManager::slotNotifyFeeds(const QStringList& feeds)
         for (QStringList::ConstIterator it = feeds.begin(); it != feeds.end(); ++it)
             message += *it + '\n';
         //KNotifyClient::Instance inst(m_instance);
-        KNotification::event("feed_added", i18n("Feeds added:\n %1", message), QPixmap() ,m_widget);
+        KNotification::event("FeedAdded", i18n("Feeds added:\n %1", message), QPixmap() ,m_widget, KNotification::CloseOnTimeout, m_instance);
     }
 }
 
@@ -92,20 +92,18 @@ void NotificationManager::doNotify()
 {
     QString message = "<html><body>";
     QString feedTitle;
-    QList<Article>::ConstIterator it = m_articles.constBegin();
-    QList<Article>::ConstIterator en = m_articles.constEnd();
-    for (; it != en; ++it)
+
+    Q_FOREACH( const Article& i, m_articles )
     {
-        if (feedTitle != (*it).feed()->title())
+        if (feedTitle != i.feed()->title())
         {
-            feedTitle = (*it).feed()->title();
+            feedTitle = i.feed()->title();
             message += QString("<p><b>%1:</b></p>").arg(feedTitle);
         }
-        message += (*it).title() + "<br>";
+        message += i.title() + "<br>";
     }
     message += "</body></html>";
-    //KNotifyClient::Instance inst(m_instance);
-    KNotification::event("new_articles", message,QPixmap() ,m_widget);
+    KNotification::event("NewArticles", message, QPixmap() ,m_widget, KNotification::CloseOnTimeout, m_instance);
 
     m_articles.clear();
     m_running = false;
@@ -125,16 +123,16 @@ void NotificationManager::slotIntervalCheck()
         m_addedInLastInterval = false;
         QTimer::singleShot(m_checkInterval, this, SLOT(slotIntervalCheck()));
     }
-    
+
 }
 
-NotificationManager* NotificationManager::m_self;
-static K3StaticDeleter<NotificationManager> notificationmanagersd;
+NotificationManager* NotificationManager::m_self = 0;
 
 NotificationManager* NotificationManager::self()
 {
+    static NotificationManager self;
     if (!m_self)
-        m_self = notificationmanagersd.setObject(m_self, new NotificationManager);
+        m_self = &self;
     return m_self;
 }
 
