@@ -153,8 +153,14 @@ void Groupware::finishHandlingInvitation()
 
   KCalCore::Incidence::Ptr existingIncidence = calendar->incidenceFromSchedulingID( incidence->uid() );
   if ( existingIncidence ) {
-    kDebug() << "cloning";
     existingIncidence = KCalCore::Incidence::Ptr( existingIncidence->clone() );
+    const bool willCrash = existingIncidence ? ( calendar->incidence( existingIncidence->uid() ) == 0 ) : false;
+
+    kDebug() << "cloning. SchedulingId=" << incidence->uid()
+             << "; SchedulingId2="       << (existingIncidence ? existingIncidence->schedulingID() : QLatin1String("invalid"))
+             << "; new uid="             << (existingIncidence ? existingIncidence->uid() : QLatin1String("invalid"))
+             << "; willCrash="           << willCrash
+             << "; action="               << action;
   }
 
   MailScheduler scheduler( calendar );
@@ -214,6 +220,7 @@ void Groupware::finishHandlingInvitation()
 
   if ( existingIncidence ) {
     KCalCore::Incidence::Ptr changedIncidence = calendar->incidence( existingIncidence->uid() );
+    Q_ASSERT( changedIncidence );
     if ( !changedIncidence->dirtyFields().isEmpty() ) {
       calendar->changeIncidence( changedIncidence );
     }
