@@ -43,6 +43,7 @@
 
 #include <KCalCore/ICalFormat>
 #include <KCalCore/MemoryCalendar>
+#include <KCalUtils/Stringify>
 
 #include <KMessageBox>
 #include <KStandardDirs>
@@ -57,7 +58,7 @@ enum Tabs {
   AttendeesTab,
   AlarmsTab,
   RecurrenceTab,
-  AttachmentsTab,
+  AttachmentsTab
 };
 
 class EventOrTodoDialogPrivate : public ItemEditorUi
@@ -78,7 +79,7 @@ class EventOrTodoDialogPrivate : public ItemEditorUi
     IncidenceAttendee *mIeAttendee;
     IncidenceRecurrence *mIeRecurrence;
     bool mInitiallyDirty;
-
+    Akonadi::Item mItem;
   public:
     EventOrTodoDialogPrivate( EventOrTodoDialog *qq );
     ~EventOrTodoDialogPrivate();
@@ -129,6 +130,9 @@ EventOrTodoDialogPrivate::EventOrTodoDialogPrivate( EventOrTodoDialog *qq )
 
   mCalSelector->setAccessRightsFilter( Akonadi::Collection::CanCreateItem );
 
+  q->connect( mCalSelector, SIGNAL(currentChanged(Akonadi::Collection)),
+              SLOT(handleSelectedCollectionChange(Akonadi::Collection)) );
+
   if ( CalendarSupport::KCalPrefs::instance()->useGroupwareCommunication() ) {
     mInvitationDispatcher = new InvitationDispatcher( 0, q );
     mInvitationDispatcher->setItemManager( mItemManager );
@@ -277,7 +281,8 @@ void EventOrTodoDialogPrivate::manageTemplates()
   QStringList &templates =
     IncidenceEditorNG::EditorConfig::instance()->templates( mEditor->type() );
   QPointer<IncidenceEditorNG::TemplateManagementDialog> dialog(
-      new IncidenceEditorNG::TemplateManagementDialog( q, templates, mEditor->type() ) );
+      new IncidenceEditorNG::TemplateManagementDialog( q, templates,
+                                                       KCalUtils::Stringify::incidenceType( mEditor->type() ) ) );
   q->connect( dialog, SIGNAL( loadTemplate( const QString& ) ),
               SLOT( loadTemplate( const QString& ) ) );
   q->connect( dialog, SIGNAL( templatesChanged( const QStringList& ) ),
@@ -295,7 +300,7 @@ void EventOrTodoDialogPrivate::saveTemplate( const QString &templateName )
   KCalCore::Incidence::Ptr incidence( new KCalCore::Event );
   mEditor->save( incidence );
 
-  QString fileName = "templates/" + incidence->type();
+  QString fileName = "templates/" + incidence->typeStr();
   fileName.append( '/' + templateName );
   fileName = KStandardDirs::locateLocal( "data", "korganizer/" + fileName );
 
@@ -368,7 +373,7 @@ void EventOrTodoDialogPrivate::handleItemSaveFail( EditorItemManager::SaveAction
   if ( retry ) {
     mItemManager->save();
   } else {
-    updateButtonStatus( mEditor->isDirty() );
+    updateButtonStatus( isDirty() );
     q->enableButtonOk( true );
     q->enableButtonCancel( true );
   }
@@ -393,7 +398,7 @@ void EventOrTodoDialogPrivate::handleItemSaveFinish( EditorItemManager::SaveActi
     // disabled at this point).
     q->enableButtonOk( true );
     q->enableButtonCancel( true );
-    q->enableButtonApply( mEditor->isDirty() );
+    q->enableButtonApply( isDirty() );
   }
 }
 
@@ -404,7 +409,11 @@ bool EventOrTodoDialogPrivate::hasSupportedPayload( const Akonadi::Item &item )
 
 bool EventOrTodoDialogPrivate::isDirty() const
 {
-  return mEditor->isDirty();
+  if ( mItem.isValid() ) {
+    return mEditor->isDirty() || mCalSelector->currentCollection().id() != mItem.storageCollectionId();
+  } else {
+    return mEditor->isDirty();
+  }
 }
 
 bool EventOrTodoDialogPrivate::isValid() const
@@ -440,20 +449,29 @@ void EventOrTodoDialogPrivate::load( const Akonadi::Item &item )
   const QStringList allEmails = IncidenceEditorNG::EditorConfig::instance()->allEmails();
   KCalCore::Attendee::Ptr me = incidence->attendeeByMails( allEmails );
 
-  if ( incidence->attendeeCount() > 1 &&
+  if ( incidence->attendeeCount() > 1 && // >1 because you won't drink alone
        me && ( me->status() == KCalCore::Attendee::NeedsAction ||
                me->status() == KCalCore::Attendee::Tentative ||
                me->status() == KCalCore::Attendee::InProcess ) ) {
+    // Show the invitation bar: "You are invited [accept] [decline]"
     mUi->mInvitationBar->show();
   } else {
     mUi->mInvitationBar->hide();
   }
 
-  mCalSelector->setMimeTypeFilter( QStringList() << incidence->mimeType() << "text/calendar" );
+  kDebug() << "Loading item " << item.id() << "; parent " << item.parentCollection().id()
+           << "; storage " << item.storageCollectionId();
+
   if ( item.parentCollection().isValid() ) {
     mCalSelector->setDefaultCollection( item.parentCollection() );
   }
 
+  if ( !mCalSelector->mimeTypeFilter().contains( "text/calendar" ) ||
+       !mCalSelector->mimeTypeFilter().contains( incidence->mimeType() ) )
+  {
+    mCalSelector->setMimeTypeFilter( QStringList() << incidence->mimeType() << "text/calendar" );
+  }
+
   if ( mEditor->type() == KCalCore::Incidence::TypeTodo ) {
     q->setWindowIcon( SmallIcon( "view-calendar-tasks" ) );
   } else if ( mEditor->type() == KCalCore::Incidence::TypeEvent ) {
@@ -467,6 +485,8 @@ void EventOrTodoDialogPrivate::load( const Akonadi::Item &item )
   handleRecurrenceChange( mIeRecurrence->currentRecurrenceType() );
   handleAlarmCountChange( incidence->alarms().count() );
 
+  mItem = item;
+
   q->show();
 }
 
@@ -493,6 +513,11 @@ Akonadi::Item EventOrTodoDialogPrivate::save( const Akonadi::Item &item )
 
   // Make sure that we don't loose uid for existing incidence
   newIncidence->setUid( mEditor->incidence<KCalCore::Incidence>()->uid() );
+
+  // Mark the incidence as changed
+  if ( mItem.isValid() )
+    newIncidence->setRevision( newIncidence->revision() + 1 );
+
   result.setPayload<KCalCore::Incidence::Ptr>( newIncidence );
   return result;
 }
@@ -507,7 +532,7 @@ void EventOrTodoDialogPrivate::reject( RejectReason reason, const QString &error
   Q_UNUSED( reason );
 
   Q_Q( EventOrTodoDialog );
-  kDebug() << "Rejecting:" << errorMessage;
+  kError() << "Rejecting:" << errorMessage;
   q->deleteLater();
 }
 
@@ -547,7 +572,6 @@ EventOrTodoDialog::EventOrTodoDialog( QWidget *parent, Qt::WFlags flags )
   setModal( false );
   showButtonSeparator( false );
 
-  // TODO: Implement these.
   connect( d->mUi->mAcceptInvitationButton, SIGNAL(clicked()),
            d->mIeAttendee, SLOT(acceptForMe()) );
   connect( d->mUi->mAcceptInvitationButton, SIGNAL(clicked()),
@@ -607,7 +631,7 @@ void EventOrTodoDialog::slotButtonClicked( int button )
   switch( button ) {
   case KDialog::Ok:
   {
-    if ( d->mEditor->isDirty() || d->mInitiallyDirty ) {
+    if ( d->isDirty() || d->mInitiallyDirty ) {
       enableButtonOk( false );
       enableButtonCancel( false );
       enableButtonApply( false );
@@ -631,11 +655,11 @@ void EventOrTodoDialog::slotButtonClicked( int button )
     break;
   }
   case KDialog::Cancel:
-    if ( d->mEditor->isDirty() &&
+    if ( d->isDirty() &&
          KMessageBox::questionYesNo( this, i18nc( "@info", "Do you really want to cancel?" ),
                  i18nc( "@title:window", "KOrganizer Confirmation" ) ) == KMessageBox::Yes ) {
       KDialog::reject(); // Discard current changes
-    } else if ( !d->mEditor->isDirty() ) {
+    } else if ( !d->isDirty() ) {
       KDialog::reject(); // No pending changes, just close the dialog.
     } // else { // the user wasn't finished editting after all }
     break;
@@ -654,4 +678,12 @@ void EventOrTodoDialog::setInitiallyDirty( bool initiallyDirty )
   d->mInitiallyDirty = initiallyDirty;
 }
 
+void EventOrTodoDialog::handleSelectedCollectionChange( const Akonadi::Collection &collection )
+{
+  Q_D( EventOrTodoDialog );
+  if ( d->mItem.parentCollection().isValid() ) {
+    enableButton( Apply, collection.id() != d->mItem.parentCollection().id() );
+  }
+}
+
 #include "eventortododialog.moc"
