@@ -32,6 +32,7 @@
 #include "functions.h"
 #include "kalarmapp.h"
 #include "mainwindow.h"
+#include "messagebox.h"
 #include "preferences.h"
 
 #ifdef USE_AKONADI
@@ -44,7 +45,6 @@
 
 #include <kglobal.h>
 #include <klocale.h>
-#include <kmessagebox.h>
 #include <kstandarddirs.h>
 #ifndef USE_AKONADI
 #include <kconfig.h>
@@ -308,7 +308,8 @@ int AlarmCalendar::load()
         if (!KIO::NetAccess::download(mUrl, tmpFile, MainWindow::mainMainWindow()))
         {
             kError() << "Download failure";
-            KMessageBox::error(0, i18nc("@info", "Cannot download calendar: <filename>%1</filename>", mUrl.prettyUrl()));
+            KAMessageBox::error(MainWindow::mainMainWindow(),
+                                i18nc("@info", "Cannot download calendar: <filename>%1</filename>", mUrl.prettyUrl()));
             return -1;
         }
         kDebug() << "--- Downloaded to" << tmpFile;
@@ -329,7 +330,8 @@ int AlarmCalendar::load()
             if (!fi.size())
                 return 0;     // file is zero length
             kError() << "Error loading calendar file '" << tmpFile <<"'";
-            KMessageBox::error(0, i18nc("@info", "<para>Error loading calendar:</para><para><filename>%1</filename></para><para>Please fix or delete the file.</para>", mUrl.prettyUrl()));
+            KAMessageBox::error(MainWindow::mainMainWindow(),
+                                i18nc("@info", "<para>Error loading calendar:</para><para><filename>%1</filename></para><para>Please fix or delete the file.</para>", mUrl.prettyUrl()));
             // load() could have partially populated the calendar, so clear it out
 #ifdef USE_AKONADI
             mCalendarStorage->calendar()->close();
@@ -423,7 +425,8 @@ bool AlarmCalendar::saveCal(const QString& newFile)
 #endif
         {
             kError() << "Saving" << saveFilename << "failed.";
-            KMessageBox::error(0, i18nc("@info", "Failed to save calendar to <filename>%1</filename>", mICalUrl.prettyUrl()));
+            KAMessageBox::error(MainWindow::mainMainWindow(),
+                                i18nc("@info", "Failed to save calendar to <filename>%1</filename>", mICalUrl.prettyUrl()));
             return false;
         }
 
@@ -432,7 +435,8 @@ bool AlarmCalendar::saveCal(const QString& newFile)
             if (!KIO::NetAccess::upload(saveFilename, mICalUrl, MainWindow::mainMainWindow()))
             {
                 kError() << saveFilename << "upload failed.";
-                KMessageBox::error(0, i18nc("@info", "Cannot upload calendar to <filename>%1</filename>", mICalUrl.prettyUrl()));
+                KAMessageBox::error(MainWindow::mainMainWindow(),
+                                    i18nc("@info", "Cannot upload calendar to <filename>%1</filename>", mICalUrl.prettyUrl()));
                 return false;
             }
         }
@@ -854,7 +858,7 @@ bool AlarmCalendar::importAlarms(QWidget* parent, AlarmResource* resource)
         if (!KStandardDirs::exists(filename))
         {
             kDebug() << "File '" << url.prettyUrl() <<"' not found";
-            KMessageBox::error(parent, i18nc("@info", "Could not load calendar <filename>%1</filename>.", url.prettyUrl()));
+            KAMessageBox::error(parent, i18nc("@info", "Could not load calendar <filename>%1</filename>.", url.prettyUrl()));
             return false;
         }
     }
@@ -863,7 +867,7 @@ bool AlarmCalendar::importAlarms(QWidget* parent, AlarmResource* resource)
         if (!KIO::NetAccess::download(url, filename, MainWindow::mainMainWindow()))
         {
             kError() << "Download failure";
-            KMessageBox::error(parent, i18nc("@info", "Cannot download calendar: <filename>%1</filename>", url.prettyUrl()));
+            KAMessageBox::error(parent, i18nc("@info", "Cannot download calendar: <filename>%1</filename>", url.prettyUrl()));
             return false;
         }
         kDebug() << "--- Downloaded to" << filename;
@@ -881,7 +885,7 @@ bool AlarmCalendar::importAlarms(QWidget* parent, AlarmResource* resource)
     if (!success)
     {
         kDebug() << "Error loading calendar '" << filename <<"'";
-        KMessageBox::error(parent, i18nc("@info", "Could not load calendar <filename>%1</filename>.", url.prettyUrl()));
+        KAMessageBox::error(parent, i18nc("@info", "Could not load calendar <filename>%1</filename>.", url.prettyUrl()));
     }
     else
     {
@@ -1062,7 +1066,8 @@ bool AlarmCalendar::exportAlarms(const KAEvent::List& events, QWidget* parent)
         if (fi.size())
         {
             kError() << "Error loading calendar file" << file << "for append";
-            KMessageBox::error(0, i18nc("@info", "Error loading calendar to append to:<nl/><filename>%1</filename>", url.prettyUrl()));
+            KAMessageBox::error(MainWindow::mainMainWindow(),
+                                i18nc("@info", "Error loading calendar to append to:<nl/><filename>%1</filename>", url.prettyUrl()));
             return false;
         }
     }
@@ -1111,13 +1116,15 @@ bool AlarmCalendar::exportAlarms(const KAEvent::List& events, QWidget* parent)
 #endif
     {
         kError() << file << ": failed";
-        KMessageBox::error(0, i18nc("@info", "Failed to save new calendar to:<nl/><filename>%1</filename>", url.prettyUrl()));
+        KAMessageBox::error(MainWindow::mainMainWindow(),
+                            i18nc("@info", "Failed to save new calendar to:<nl/><filename>%1</filename>", url.prettyUrl()));
         success = false;
     }
     else if (!local  &&  !KIO::NetAccess::upload(file, url, parent))
     {
         kError() << file << ": upload failed";
-        KMessageBox::error(0, i18nc("@info", "Cannot upload new calendar to:<nl/><filename>%1</filename>", url.prettyUrl()));
+        KAMessageBox::error(MainWindow::mainMainWindow(),
+                            i18nc("@info", "Cannot upload new calendar to:<nl/><filename>%1</filename>", url.prettyUrl()));
         success = false;
     }
 #ifdef USE_AKONADI
