@@ -35,17 +35,19 @@
 #include "readerstatus.h"
 
 #include <utils/gnupg-helper.h>
-#include <utils/stl_util.h>
 #include <utils/kdsignalblocker.h>
 #include <utils/filesystemwatcher.h>
 
+#include <kleo/stl_util.h>
+
 #include <gpgme++/context.h>
 #include <gpgme++/assuanresult.h>
 #include <gpgme++/defaultassuantransaction.h>
 #include <gpgme++/key.h>
 #include <gpgme++/keylistresult.h>
 
-#include <QFileSystemWatcher>
+#include <gpg-error.h>
+
 #include <QStringList>
 #include <QDir>
 #include <QFileInfo>
@@ -56,9 +58,11 @@
 #include <QPointer>
 #include <QDebug>
 
+#ifndef _WIN32_WCE
 #include <boost/algorithm/string/split.hpp>
 #include <boost/algorithm/string/classification.hpp>
 #include <boost/algorithm/string/case_conv.hpp>
+#endif
 #include <boost/static_assert.hpp>
 #include <boost/range.hpp>
 #include <boost/bind.hpp>
@@ -76,6 +80,9 @@ using namespace Kleo::SmartCard;
 using namespace GpgME;
 using namespace boost;
 
+static const unsigned int RETRY_WAIT = 2; // seconds
+static const unsigned int CHECK_INTERVAL = 2000; // msecs
+
 static ReaderStatus * self = 0;
 
 struct CardInfo {
@@ -119,27 +126,21 @@ static const char * prettyFlags[] = {
     "CardUsable",
     "CardCanLearnKeys",
     "CardHasNullPin",
+    "CardError",
 };
 BOOST_STATIC_ASSERT(( sizeof prettyFlags/sizeof *prettyFlags == ReaderStatus::NumStates ));
 
-static ReaderStatus::Status read_status( const QString & fileName ) {
+static QByteArray read_file( const QString & fileName ) {
     QFile file( fileName );
     if ( !file.exists() ) {
-        qDebug() << "read_status: file" << fileName << "does not exist";
-        return ReaderStatus::NoCard;
+        qDebug() << "read_file: file" << fileName << "does not exist";
+        return QByteArray();
     }
     if ( !file.open( QIODevice::ReadOnly ) ) {
-        qDebug() << "read_status: failed to open" << fileName << ':' << file.errorString();
-        return ReaderStatus::NoCard;
-    }
-    const QByteArray contents = file.readAll().trimmed();
-    const char ** it = std::find( begin( flags ), end( flags ), contents );
-    if ( it == end( flags ) ) {
-        qDebug() << "read_status: not found";
-        return ReaderStatus::NoCard;
-    } else {
-        return static_cast<ReaderStatus::Status>( it - begin( flags ) );
+        qDebug() << "read_file: failed to open" << fileName << ':' << file.errorString();
+        return QByteArray();
     }
+    return file.readAll().trimmed();
 }
 
 static unsigned int parseFileName( const QString & fileName, bool * ok ) {
@@ -191,10 +192,19 @@ BOOST_STATIC_ASSERT(( sizeof app_types / sizeof *app_types == ReaderStatus::NumA
 
 static ReaderStatus::AppType parse_app_type( const std::string & s ) {
     qDebug() << "parse_app_type(" << s.c_str() << ")";
+#ifndef _WIN32_WCE
     const char ** it = std::find( begin( app_types ), end( app_types ), to_lower_copy( s ) );
+#else
+    std::string lowerStr ;
+    for (std::string::const_iterator itr = s.begin();itr!=s.end();itr++) {
+      lowerStr+=tolower(*itr);
+    }
+    const char ** it = std::find( begin( app_types ), end( app_types ), lowerStr );
+#endif
     if ( it == end( app_types ) )
         return TRACE( ReaderStatus::UnknownApplication );
     return TRACE( static_cast<ReaderStatus::AppType>( it - begin( app_types ) ) );
+
 }
 
 static int parse_app_version( const std::string & s ) {
@@ -215,7 +225,7 @@ static ReaderStatus::PinState parse_pin_state( const std::string & s ) {
     }
 }
 
-static std::auto_ptr<DefaultAssuanTransaction> gpgagent_transact( const shared_ptr<Context> & gpgAgent, const char * command, Error & err ) {
+static std::auto_ptr<DefaultAssuanTransaction> gpgagent_transact( shared_ptr<Context> & gpgAgent, const char * command, Error & err ) {
     qDebug() << "gpgagent_transact(" << command << ")";
     const AssuanResult res = gpgAgent->assuanTransact( command );
     err = res.error();
@@ -223,6 +233,10 @@ static std::auto_ptr<DefaultAssuanTransaction> gpgagent_transact( const shared_p
         err = res.assuanError();
     if ( err.code() ) {
         qDebug() << "gpgagent_transact(" << command << "):" << QString::fromLocal8Bit( err.asString() );
+        if ( err.code() >= GPG_ERR_ASS_GENERAL && err.code() <= GPG_ERR_ASS_UNKNOWN_INQUIRE ) {
+            qDebug() << "Assuan problem, killing context";
+            gpgAgent.reset();
+        }
         return std::auto_ptr<DefaultAssuanTransaction>();
     }
     std::auto_ptr<AssuanTransaction> t = gpgAgent->takeLastAssuanTransaction();
@@ -230,7 +244,7 @@ static std::auto_ptr<DefaultAssuanTransaction> gpgagent_transact( const shared_p
 }
 
 // returns const std::string so template deduction in boost::split works, and we don't need a temporary
-static const std::string scd_getattr_status( const shared_ptr<Context> & gpgAgent, const char * what, Error & err ) {
+static const std::string scd_getattr_status( shared_ptr<Context> & gpgAgent, const char * what, Error & err ) {
     std::string cmd = "SCD GETATTR ";
     cmd += what;
     const std::auto_ptr<DefaultAssuanTransaction> t = gpgagent_transact( gpgAgent, cmd.c_str(), err );
@@ -243,8 +257,29 @@ static const std::string scd_getattr_status( const shared_ptr<Context> & gpgAgen
     }
 }
 
+static unsigned int parse_event_counter( const std::string & str ) {
+    unsigned int result;
+    if ( sscanf( str.c_str(), "%*u %*u %u ", &result ) == 1 )
+        return result;
+    return -1;
+}
+
+static unsigned int get_event_counter( shared_ptr<Context> & gpgAgent ) {
+    Error err;
+    const std::auto_ptr<DefaultAssuanTransaction> t = gpgagent_transact( gpgAgent, "GETEVENTCOUNTER", err );
+    if ( err.code() )
+        qDebug() << "get_event_counter(): got error" << err.asString();
+    if ( t.get() ) {
+        qDebug() << "get_event_counter(): got" << t->statusLines();
+        return parse_event_counter( t->firstStatusLine( "EVENTCOUNTER" ) );
+    } else {
+        qDebug() << "scd_getattr_status(): t == NULL";
+        return -1;
+    }
+}
+
 // returns const std::string so template deduction in boost::split works, and we don't need a temporary
-static const std::string gpgagent_data( const shared_ptr<Context> & gpgAgent, const char * what, Error & err ) {
+static const std::string gpgagent_data( shared_ptr<Context> & gpgAgent, const char * what, Error & err ) {
     const std::auto_ptr<DefaultAssuanTransaction> t = gpgagent_transact( gpgAgent, what, err );
     if ( t.get() )
         return t->data();
@@ -273,34 +308,46 @@ static bool parse_keypairinfo_and_lookup_key( Context * ctx, const std::string &
     return !e && !key.isNull();
 }
 
-static CardInfo get_more_detailed_status( const QString & fileName, unsigned int idx, const shared_ptr<Context> & gpg_agent ) {
-    qDebug() << "get_more_detailed_status(" << fileName << ',' << idx << ',' << gpg_agent.get() << ')';
+static CardInfo get_card_status( const QString & fileName, unsigned int idx, shared_ptr<Context> & gpg_agent ) {
+    qDebug() << "get_card_status(" << fileName << ',' << idx << ',' << gpg_agent.get() << ')';
     CardInfo ci( fileName, ReaderStatus::CardUsable );
     if ( idx != 0 || !gpg_agent )
         return ci;
     Error err;
     ci.serialNumber = gpgagent_data( gpg_agent, "SCD SERIALNO", err );
-    if ( err.code() )
+    if ( err.code() == GPG_ERR_CARD_NOT_PRESENT || err.code() == GPG_ERR_CARD_REMOVED ) {
+        ci.status = ReaderStatus::NoCard;
         return ci;
+    }
+    if ( err.code() ) {
+        ci.status = ReaderStatus::CardError;
+        return ci;
+    }
     ci.appType = parse_app_type( scd_getattr_status( gpg_agent, "APPTYPE", err ) );
     if ( err.code() )
         return ci;
     if ( ci.appType != ReaderStatus::NksApplication ) {
-        qDebug() << "get_more_detailed_status: not a NetKey card, giving up";
+        qDebug() << "get_card_status: not a NetKey card, giving up";
         return ci;
     }
     ci.appVersion = parse_app_version( scd_getattr_status( gpg_agent, "NKS-VERSION", err ) );
     if ( err.code() )
         return ci;
     if ( ci.appVersion != 3 ) {
-        qDebug() << "get_more_detailed_status: not a NetKey v3 card, giving up";
+        qDebug() << "get_card_status: not a NetKey v3 card, giving up";
         return ci;
     }
 
     // the following only works for NKS v3...
     std::vector<std::string> chvStatus;
     chvStatus.reserve( 4 ); // expected number of fields
+#ifdef _WIN32_WCE
+    for ( std::string::size_type b = 0, e = scd_getattr_status( gpg_agent, "CHV-STATUS", err ).find( ' \t', 0 ) ; e != std::string::npos ; b = e+1, e = scd_getattr_status( gpg_agent, "CHV-STATUS", err ).find( ' \t', b ) )
+        if ( e > b )
+            chvStatus.push_back( scd_getattr_status( gpg_agent, "CHV-STATUS", err ).substr( b, e-b ) );
+#else
     split( chvStatus, scd_getattr_status( gpg_agent, "CHV-STATUS", err ), is_any_of( " \t" ), token_compress_on );
+#endif
     if ( err.code() )
         return ci;
     std::transform( chvStatus.begin(), chvStatus.end(),
@@ -326,43 +373,35 @@ static CardInfo get_more_detailed_status( const QString & fileName, unsigned int
         return ci;
     klc->setKeyListMode( Ephemeral );
 
-    if ( kdtools::any( keyPairInfos, !bind( &parse_keypairinfo_and_lookup_key, klc.get(), _1 ) ) )
+    if ( kdtools::any( keyPairInfos, !boost::bind( &parse_keypairinfo_and_lookup_key, klc.get(), _1 ) ) )
         ci.status = ReaderStatus::CardCanLearnKeys;
 
-    qDebug() << "get_more_detailed_status: ci.status " << prettyFlags[ci.status];
+    qDebug() << "get_card_status: ci.status " << prettyFlags[ci.status];
 
     return ci;
 }
 
-static CardInfo get_card_info( const QString & fileName, unsigned int idx, const shared_ptr<Context> & gpg_agent, ReaderStatus::Status oldStatus ) {
-    qDebug() << "get_card_info(" << fileName << ',' << idx << ',' << gpg_agent.get() << ',' << prettyFlags[oldStatus] << ')';
-    const ReaderStatus::Status st = read_status( fileName );
-    if ( ( st == ReaderStatus::CardUsable || st == ReaderStatus::CardPresent ) && st != oldStatus && gpg_agent )
-        return get_more_detailed_status( fileName, idx, gpg_agent );
-    else
-        return CardInfo( fileName, st );
+static std::vector<CardInfo> update_cardinfo( const QString & gnupgHomePath, shared_ptr<Context> & gpgAgent ) {
+    qDebug() << "<update_cardinfo>";
+    const QDir gnupgHome( gnupgHomePath );
+    if ( !gnupgHome.exists() )
+        qWarning() << "update_cardinfo: gnupg home" << gnupgHomePath << "does not exist!";
+
+    const CardInfo ci = get_card_status( gnupgHome.absoluteFilePath( QLatin1String( "reader_0.status" ) ), 0, gpgAgent );
+
+    qDebug() << "</update_cardinfo>";
+    return std::vector<CardInfo>( 1, ci );
 }
 
-static std::vector<CardInfo> update_cardinfo( const QString & gnupgHomePath, const shared_ptr<Context> & gpgAgent, const std::vector<CardInfo> & oldCardInfos ) {
-    const QDir gnupgHome( gnupgHomePath );
-    if ( !gnupgHome.exists() ) {
-        qDebug() << "update_cardinfo: gnupg home" << gnupgHomePath << "does not exist!";
-        return std::vector<CardInfo>();
+static bool check_event_counter_changed( shared_ptr<Context> & gpg_agent, unsigned int & counter ) {
+    const unsigned int oldCounter = counter;
+    counter = get_event_counter( gpg_agent );
+    if ( oldCounter != counter ) {
+        qDebug() << "ReaderStatusThread[2nd]: events:" << oldCounter << "->" << counter ;
+        return true;
+    } else {
+        return false;
     }
-    const QStringList files = gnupgHome.entryList( QStringList( QLatin1String( "reader_*.status" ) ), QDir::Files, QDir::Name );
-
-    std::vector<CardInfo> result;
-    result.reserve( files.size() );
-    Q_FOREACH( const QString & file, files ) {
-        bool ok = false;
-        const unsigned int idx = parseFileName( file, &ok );
-        if ( !ok )
-            continue;
-        result.resize( idx );
-        result.push_back( get_card_info( gnupgHome.absoluteFilePath( file ), idx, gpgAgent,
-                                         idx < oldCardInfos.size() ? oldCardInfos[idx].status : ReaderStatus::NoCard ) );
-    }
-    return result;
 }
 
 struct Transaction {
@@ -372,6 +411,7 @@ struct Transaction {
     GpgME::Error error;
 };
 
+static const Transaction checkTransaction  = { "__check__",  0, 0, Error() };
 static const Transaction updateTransaction = { "__update__", 0, 0, Error() };
 static const Transaction quitTransaction   = { "__quit__",   0, 0, Error() };
 
@@ -407,6 +447,9 @@ namespace {
             m_waitForTransactions.wakeOne();
         }
 
+        // make QThread::sleep public
+        using QThread::sleep;
+
     Q_SIGNALS:
         void anyCardHasNullPinChanged( bool );
         void anyCardCanLearnKeysChanged( bool );
@@ -425,6 +468,41 @@ namespace {
             m_waitForTransactions.wakeOne();
         }
 
+        void slotReaderStatusFileChanged() {
+            const QDir gnupgHome( m_gnupgHomePath );
+            if ( !gnupgHome.exists() ) {
+                qWarning() << "ReaderStatusThread::slotReaderStatusFileChanged: gnupg home" << m_gnupgHomePath << "does not exist!";
+                return;
+            }
+
+            QStringList files = gnupgHome.entryList( QStringList( QLatin1String( "reader_*.status" ) ), QDir::Files, QDir::Name );
+            bool * dummy = 0;
+            kdtools::sort( files, boost::bind( parseFileName, _1, dummy ) < boost::bind( parseFileName, _2, dummy ) );
+
+            std::vector<QByteArray> contents;
+
+            Q_FOREACH( const QString & file, files ) {
+                bool ok = false;
+                const unsigned int idx = parseFileName( file, &ok );
+                if ( !ok ) {
+                    qDebug() << "filename" << file << ": cannot parse reader slot number";
+                    continue;
+                }
+                assert( idx >= contents.size() );
+                contents.resize( idx );
+                contents.push_back( read_file( gnupgHome.absoluteFilePath( file ) ) );
+            }
+
+            // canonicalise by removing empty stuff from the end
+            while ( !contents.empty() && contents.back().isEmpty() )
+                contents.pop_back();
+
+            if ( contents != readerStatusFileContents )
+                ping();
+
+            readerStatusFileContents.swap( contents );
+        }
+
     private Q_SLOTS:
         void slotOneTransactionFinished() {
             std::list<Transaction> ft;
@@ -437,7 +515,9 @@ namespace {
 
     private:
         /* reimp */ void run() {
-            const shared_ptr<Context> gpgAgent( Context::createForEngine( AssuanEngine ) );
+
+            shared_ptr<Context> gpgAgent;
+            unsigned int eventCounter = -1;
 
             while ( true ) {
 
@@ -446,12 +526,21 @@ namespace {
                 std::list<Transaction> item;
                 std::vector<CardInfo> oldCardInfos;
 
+                if ( !gpgAgent ) {
+                    Error err;
+                    std::auto_ptr<Context> c = Context::createForEngine( AssuanEngine, &err );
+                    if ( err.code() == GPG_ERR_NOT_SUPPORTED )
+                        return;
+                    gpgAgent = c;
+                }
+
                 KDAB_SYNCHRONIZED( m_mutex ) {
 
                     while ( m_transactions.empty() ) {
                         // go to sleep waiting for more work:
                         qDebug( "ReaderStatusThread[2nd]: .zZZ" );
-                        m_waitForTransactions.wait( &m_mutex );
+                        if ( !m_waitForTransactions.wait( &m_mutex, CHECK_INTERVAL ) )
+                            m_transactions.push_front( checkTransaction );
                         qDebug( "ReaderStatusThread[2nd]: .oOO" );
                     }
 
@@ -476,10 +565,14 @@ namespace {
                 if ( nullSlot && command == quitTransaction.command )
                     return; // quit
 
-                if ( nullSlot && command == updateTransaction.command ) {
+                if ( nullSlot && command == updateTransaction.command ||
+                     nullSlot && command == checkTransaction.command ) {
+
+                    if ( nullSlot && command == checkTransaction.command && !check_event_counter_changed( gpgAgent, eventCounter ) )
+                        continue; // early out
 
                     std::vector<CardInfo> newCardInfos
-                        = update_cardinfo( m_gnupgHomePath, gpgAgent, oldCardInfos );
+                        = update_cardinfo( m_gnupgHomePath, gpgAgent );
 
                     newCardInfos.resize( std::max( newCardInfos.size(), oldCardInfos.size() ) );
                     oldCardInfos.resize( std::max( newCardInfos.size(), oldCardInfos.size() ) );
@@ -494,6 +587,7 @@ namespace {
                     unsigned int idx = 0;
                     bool anyLC = false;
                     bool anyNP = false;
+                    bool anyError = false;
                     while ( nit != nend && oit != oend ) {
                         if ( nit->status != oit->status ) {
                             qDebug() << "ReaderStatusThread[2nd]: slot" << idx << ":" << prettyFlags[oit->status] << "->" << prettyFlags[nit->status];
@@ -503,6 +597,8 @@ namespace {
                             anyLC = true;
                         if ( nit->status == ReaderStatus::CardHasNullPin )
                             anyNP = true;
+                        if ( nit->status == ReaderStatus::CardError )
+                            anyError = true;
                         ++nit;
                         ++oit;
                         ++idx;
@@ -511,6 +607,9 @@ namespace {
                     emit anyCardHasNullPinChanged( anyNP );
                     emit anyCardCanLearnKeysChanged( anyLC );
 
+                    if ( anyError )
+                        gpgAgent.reset();
+
                 } else {
 
                     (void)gpgagent_transact( gpgAgent, command.constData(), item.front().error );
@@ -522,6 +621,16 @@ namespace {
                     emit oneTransactionFinished();
 
                 }
+
+                // update event counter in case anything above changed
+                // it:
+                if ( gpgAgent )
+                    eventCounter = get_event_counter( gpgAgent );
+                else
+                    eventCounter = -1;
+
+                qDebug() << "eventCounter:" << eventCounter;
+
             }
         }
 
@@ -529,6 +638,7 @@ namespace {
         mutable QMutex m_mutex;
         QWaitCondition m_waitForTransactions;
         const QString m_gnupgHomePath;
+        std::vector<QByteArray> readerStatusFileContents;
         // protected by m_mutex:
         std::vector<CardInfo> m_cardInfos;
         std::list<Transaction> m_transactions, m_finishedTransactions;
@@ -560,7 +670,7 @@ public:
         connect( this, SIGNAL(anyCardCanLearnKeysChanged(bool)),
                  q, SIGNAL(anyCardCanLearnKeysChanged(bool)) );
 
-        connect( &watcher, SIGNAL(triggered()), this, SLOT(ping()) );
+        connect( &watcher, SIGNAL(triggered()), this, SLOT(slotReaderStatusFileChanged()) );
 
     }
     ~Private() {
@@ -573,11 +683,11 @@ public:
 
 private:
     bool anyCardHasNullPinImpl() const {
-        return kdtools::any( cardInfos(), bind( &CardInfo::status, _1 ) == CardHasNullPin );
+        return kdtools::any( cardInfos(), boost::bind( &CardInfo::status, _1 ) == CardHasNullPin );
     }
 
     bool anyCardCanLearnKeysImpl() const {
-        return kdtools::any( cardInfos(), bind( &CardInfo::status, _1 ) == CardCanLearnKeys );
+        return kdtools::any( cardInfos(), boost::bind( &CardInfo::status, _1 ) == CardCanLearnKeys );
     }
 
 private:
@@ -588,12 +698,16 @@ private:
 ReaderStatus::ReaderStatus( QObject * parent )
     : QObject( parent ), d( new Private( this ) )
 {
-    QTimer::singleShot( 500, d.get(), SLOT(start()) );
     self = this;
 }
 
 ReaderStatus::~ReaderStatus() { self = 0; }
 
+// slot
+void ReaderStatus::startMonitoring() {
+    d->start();
+}
+
 // static
 ReaderStatus * ReaderStatus::mutableInstance() {
     return self;
