@@ -163,11 +163,12 @@ public:
   virtual void defaults();
 
 protected:
+  virtual void showEvent ( QShowEvent * event );
   void addTab( ConfigModuleTab* tab, const QString & title );
 
 private:
   KTabWidget *mTabWidget;
-
+  bool mWasInitialized;
 };
 
 
@@ -537,6 +538,7 @@ protected slots:
 
 private:
   virtual void doLoadFromGlobalSettings();
+  virtual void doResetToDefaultsOther();
 
 private:
   QCheckBox     *mAutoAppSignFileCheck;
