@@ -103,6 +103,8 @@ using KMail::SecondaryWindow;
 #include <akonadi/itemmovejob.h>
 #include <akonadi/itemcopyjob.h>
 #include <akonadi/itemdeletejob.h>
+#include <mailtransport/transportattribute.h>
+#include <mailtransport/sentbehaviourattribute.h>
 
 #include <messagelist/pane.h>
 
@@ -550,6 +552,8 @@ KMEditMsgCommand::KMEditMsgCommand( QWidget *parent, const Akonadi::Item&msg, bo
   , mDeleteFromSource( deleteFromSource )
 {
   fetchScope().fetchFullPayload( true );
+  fetchScope().fetchAttribute<MailTransport::TransportAttribute>();
+  fetchScope().fetchAttribute<MailTransport::SentBehaviourAttribute>();
   fetchScope().setAncestorRetrieval( Akonadi::ItemFetchScope::Parent );
   setDeletesItself( true );
 }
@@ -570,7 +574,19 @@ KMCommand::Result KMEditMsgCommand::execute()
   KMail::Composer *win = KMail::makeComposer();
   win->setMsg( msg, false, true );
   win->setFolder( item.parentCollection() );
+  const MailTransport::TransportAttribute *transportAttribute = item.attribute<MailTransport::TransportAttribute>();
+  if ( transportAttribute ) {
+    win->setCurrentTransport( transportAttribute->transportId() );
+  }
+
+  const MailTransport::SentBehaviourAttribute *sentAttribute = item.attribute<MailTransport::SentBehaviourAttribute>();
+  if ( sentAttribute ) {
+    if ( sentAttribute->sentBehaviour() == MailTransport::SentBehaviourAttribute::MoveToCollection )
+      win->setFcc( QString::number( sentAttribute->moveToCollection().id() ) );
+  }
   win->show();
+  if ( mDeleteFromSource )
+    win->setModified( true );
 
   return OK;
 }
@@ -790,6 +806,7 @@ KMNoQuoteReplyToCommand::KMNoQuoteReplyToCommand( QWidget *parent,
                                                   const Akonadi::Item &msg )
   : KMCommand( parent, msg )
 {
+    fetchScope().setAncestorRetrieval( Akonadi::ItemFetchScope::Parent );
 }
 
 KMCommand::Result KMNoQuoteReplyToCommand::execute()
@@ -949,12 +966,8 @@ KMCommand::Result KMForwardCommand::execute()
       MessageFactory factory( KMime::Message::Ptr( new KMime::Message ), firstItem.id(), firstItem.parentCollection() );
       factory.setIdentityManager( KMKernel::self()->identityManager() );
       factory.setFolderIdentity( MailCommon::Util::folderIdentity( firstItem ) );
-      // get a list of messages
-      QList< KMime::Message::Ptr > msgs;
-      foreach( const Akonadi::Item& item, msgList )
-        msgs << MessageCore::Util::message( item );
-      
-      QPair< KMime::Message::Ptr, KMime::Content* > fwdMsg = factory.createForwardDigestMIME( msgs );
+
+      QPair< KMime::Message::Ptr, KMime::Content* > fwdMsg = factory.createForwardDigestMIME(msgList );
       KMail::Composer * win = KMail::makeComposer( fwdMsg.first, KMail::Composer::Forward, mIdentity );
       win->addAttach( fwdMsg.second );
       win->show();
@@ -962,7 +975,7 @@ KMCommand::Result KMForwardCommand::execute()
     } else if ( answer == KMessageBox::No ) {// NO MIME DIGEST, Multiple forward
       QList<Akonadi::Item>::const_iterator it;
       QList<Akonadi::Item>::const_iterator end( msgList.constEnd() );
-      
+
       for ( it = msgList.constBegin(); it != end; ++it ) {
         KMime::Message::Ptr msg = MessageCore::Util::message( *it );
         if ( !msg )
@@ -1037,7 +1050,7 @@ KMCommand::Result KMForwardAttachedCommand::execute()
   MessageFactory factory( KMime::Message::Ptr( new KMime::Message ), firstItem.id(), firstItem.parentCollection() );
   factory.setIdentityManager( KMKernel::self()->identityManager() );
   factory.setFolderIdentity( MailCommon::Util::folderIdentity( firstItem ) );
-    
+
   QPair< KMime::Message::Ptr, QList< KMime::Content* > > fwdMsg = factory.createAttachedForward( msgList );
   if ( !mWin ) {
     mWin = KMail::makeComposer( fwdMsg.first, KMail::Composer::Forward, mIdentity );
@@ -1054,6 +1067,9 @@ KMRedirectCommand::KMRedirectCommand( QWidget *parent,
   : KMCommand( parent, msg )
 {
   fetchScope().fetchFullPayload( true );
+  fetchScope().fetchAttribute<MailTransport::SentBehaviourAttribute>();
+  fetchScope().fetchAttribute<MailTransport::TransportAttribute>();
+
   fetchScope().setAncestorRetrieval( Akonadi::ItemFetchScope::Parent );
 }
 
@@ -1082,7 +1098,25 @@ KMCommand::Result KMRedirectCommand::execute()
   factory.setIdentityManager( KMKernel::self()->identityManager() );
   factory.setFolderIdentity( MailCommon::Util::folderIdentity( item ) );
 
-  const KMime::Message::Ptr newMsg = factory.createRedirect( dlg->to() );
+  const MailTransport::TransportAttribute *transportAttribute = item.attribute<MailTransport::TransportAttribute>();
+  int transportId = -1;
+  if ( transportAttribute ) {
+    transportId = transportAttribute->transportId();
+    const MailTransport::Transport *transport = MailTransport::TransportManager::self()->transportById( transportId );
+    if ( !transport ) {
+      transportId = -1;
+    }
+  }
+
+  const MailTransport::SentBehaviourAttribute *sentAttribute = item.attribute<MailTransport::SentBehaviourAttribute>();
+  QString fcc;
+  if ( sentAttribute ) {
+    if ( sentAttribute->sentBehaviour() == MailTransport::SentBehaviourAttribute::MoveToCollection )
+      fcc =  QString::number( sentAttribute->moveToCollection().id() );
+  }
+
+
+  const KMime::Message::Ptr newMsg = factory.createRedirect( dlg->to(), transportId, fcc );
   if ( !newMsg )
     return Failed;
 
@@ -1211,7 +1245,7 @@ KMCommand::Result KMCustomForwardCommand::execute()
         if ( id == 0 )
           id = mIdentity;
         {
-          KMail::Composer * win = KMail::makeComposer( fwdMsg, KMail::Composer::Forward, id );
+          KMail::Composer * win = KMail::makeComposer( fwdMsg, KMail::Composer::Forward, id,QString(), mTemplate );
           win->show();
         }
 
@@ -1349,10 +1383,10 @@ KMCommand::Result KMSetStatusCommand::execute()
       if ( !item.hasFlag( flag ) ) {
         item.setFlag( flag );
         itemsToModify.push_back( item );
-      } 
+      }
     }
   }
-  
+
   if ( itemsToModify.isEmpty() ) {
     slotModifyItemDone( 0 ); // pretend we did something
   } else {
@@ -1583,10 +1617,12 @@ KMCommand::Result KMMoveCommand::execute()
       }
       kmkernel->undoStack()->addMsgToAction( undoId, item );
     }
-  }
-  else {
-    Akonadi::ItemDeleteJob *job = new Akonadi::ItemDeleteJob( retrievedMsgs(), this );
-    connect( job, SIGNAL( result( KJob* ) ), this, SLOT( slotMoveResult( KJob* ) ) );
+  } else {
+    const QList<Akonadi::Item> retrievedList = retrievedMsgs();
+    if ( !retrievedList.isEmpty() ) {
+      Akonadi::ItemDeleteJob *job = new Akonadi::ItemDeleteJob( retrievedList, this );
+      connect( job, SIGNAL( result( KJob* ) ), this, SLOT( slotMoveResult( KJob* ) ) );
+    }
   }
 
 #if 0 //TODO port to akonadi
