@@ -169,6 +169,15 @@ class KMComposeWin : public KMail::Composer
     void setMsg( const KMime::Message::Ptr &newMsg, bool mayAutoSign=true,
                  bool allowDecryption=false, bool isModified=false );
 
+    void setCurrentTransport( int transportId );
+
+    /**
+     * Use the given folder as sent-mail folder if the given folder exists.
+     * Else show an error message and use the default sent-mail folder as
+     * sent-mail folder.
+     */
+    void setFcc( const QString &idString );
+
      /**
       * Disables word wrap completely. No wrapping at all will occur, not even
       * at the right end of the editor.
@@ -231,8 +240,14 @@ class KMComposeWin : public KMail::Composer
      * message to a known recipient.
      */
      void setFocusToSubject();
+  
+     void addImageAsAttachement(const QByteArray & imageData);
 
   private:
+    bool isComposerModified() const;
+    void changeModifiedState( bool modified );
+
+  
     /**
      * determines whether inline signing/encryption is selected
      */
@@ -252,6 +267,9 @@ class KMComposeWin : public KMail::Composer
     {
       mSigningAndEncryptionExplicitlyDisabled = v;
     }
+  public slots: // kmkernel, callback
+    void autoSaveMessage(bool force = false);
+  void slotFetchJob(KJob*);
 
   private slots:
      /**
@@ -381,8 +399,6 @@ class KMComposeWin : public KMail::Composer
     void slotSpellcheckDoneClearStatus();
 
   public slots: // kmkernel
-    void autoSaveMessage();
-
     /**
      * Set whether the message should be treated as modified or not.
      */
@@ -405,6 +421,9 @@ class KMComposeWin : public KMail::Composer
     void slotSpellCheckingStatus( const QString & status );
 
     void slotDelayedApplyTemplate( KJob* );
+    void slotSpellCheckingLanguage(const QString& language);
+    void forceAutoSaveMessage();
+  
 
   public: // kmcommand
     // FIXME we need to remove these, but they're pure virtual in Composer.
@@ -489,13 +508,6 @@ class KMComposeWin : public KMail::Composer
     QString from() const;
     QString replyTo() const;
 
-    /**
-     * Use the given folder as sent-mail folder if the given folder exists.
-     * Else show an error message and use the default sent-mail folder as
-     * sent-mail folder.
-     */
-    void setFcc( const QString &idString );
-
     void setCharset( const QByteArray &charset );
     void setAutoCharset();
 
@@ -696,6 +708,7 @@ class KMComposeWin : public KMail::Composer
     bool mPreventFccOverwrite;
     bool mCheckForForgottenAttachments;
     bool mIgnoreStickyFields;
+  bool mWasModified;
 };
 
 #endif
