@@ -329,6 +329,9 @@ public:
 
   bool isImapFolder( const Akonadi::Collection& ) const;
 
+  //sets online status for akonadi accounts. true for online, false for offline
+  void setAccountStatus(bool);
+
   const KComponentData &xmlGuiInstance() { return mXmlGuiInstance; }
   void setXmlGuiInstance( const KComponentData &instance ) { mXmlGuiInstance = instance; }
 
@@ -405,7 +408,7 @@ public:
 
   /*reimp*/ QStringList customTemplates();
 
-  void checkFolderFromResources( const Akonadi::Collection::Id& collectionId );
+  void checkFolderFromResources( const Akonadi::Collection::List& collectionList );
 
   const QAbstractItemModel* treeviewModelSelection();
 
@@ -436,7 +439,6 @@ public slots:
   void slotRunBackgroundTasks();
 
   void slotConfigChanged();
-  void slotCollectionMoved( const Akonadi::Collection &collection, const Akonadi::Collection &source, const Akonadi::Collection &destination );
 
 signals:
   void configChanged();
@@ -460,6 +462,11 @@ private slots:
   void akonadiStateChanged( Akonadi::ServerManager::State );
   void slotProgressItemCompletedOrCanceled( KPIM::ProgressItem * item);
   void instanceError(const Akonadi::AgentInstance& instance, const QString & message);
+  void slotCollectionMoved( const Akonadi::Collection &collection, const Akonadi::Collection &source, const Akonadi::Collection &destination );
+  void slotCollectionRemoved(const Akonadi::Collection& col);
+  void slotDeleteIdentity( uint identity);
+  void slotInstanceRemoved(const Akonadi::AgentInstance&);
+  
 private:
   void migrateFromKMail1();
   void openReader( bool onlyCheck );
