@@ -129,8 +129,9 @@ void KMReaderMainWin::setUseFixedFont( bool useFixedFont )
   mReaderWin->setUseFixedFont( useFixedFont );
 }
 
-void KMReaderMainWin::showMessage( const QString & encoding, const Akonadi::Item &msg )
+void KMReaderMainWin::showMessage( const QString & encoding, const Akonadi::Item &msg, const Akonadi::Collection& parentCollection )
 {
+  mParentCollection = parentCollection;
   mReaderWin->setOverrideEncoding( encoding );
   mReaderWin->setMessage( msg, MessageViewer::Viewer::Force );
   KMime::Message::Ptr message = MessageCore::Util::message( msg );
@@ -139,8 +140,7 @@ void KMReaderMainWin::showMessage( const QString & encoding, const Akonadi::Item
   mMsg = msg;
   mMsgActions->setCurrentMessage( msg );
 
-  const Akonadi::Collection parent = msg.parentCollection();
-  const bool canChange = parent.isValid() ? !( parent.rights() & Akonadi::Collection::ReadOnly ) : false;
+  const bool canChange = mParentCollection.isValid() ? !( mParentCollection.rights() & Akonadi::Collection::ReadOnly ) : false;
   mTrashAction->setEnabled( canChange );
 
   menuBar()->show();
@@ -173,12 +173,20 @@ void KMReaderMainWin::slotReplyOrForwardFinished()
   }
 }
 
+Akonadi::Collection KMReaderMainWin::parentCollection() const
+{
+  if ( mParentCollection.isValid() )
+    return mParentCollection;
+  else
+    return mMsg.parentCollection();
+}
+
 //-----------------------------------------------------------------------------
 void KMReaderMainWin::slotTrashMsg()
 {
   if ( !mMsg.isValid() )
     return;
-  KMTrashMsgCommand *command = new KMTrashMsgCommand( mMsg.parentCollection(), mMsg, -1 );
+  KMTrashMsgCommand *command = new KMTrashMsgCommand( parentCollection(), mMsg, -1 );
   command->start();
   close();
 }
@@ -188,8 +196,9 @@ void KMReaderMainWin::slotForwardInlineMsg()
 {
   if ( !mReaderWin->message().hasPayload<KMime::Message::Ptr>() ) return;
    KMCommand *command = 0;
-   if ( mReaderWin->message().isValid() && mReaderWin->message().parentCollection().isValid() ) {
-     QSharedPointer<FolderCollection> fd = FolderCollection::forCollection( mReaderWin->message().parentCollection(), false );
+   const Akonadi::Collection parentCol = mReaderWin->message().parentCollection();
+   if ( parentCol.isValid() ) {
+     QSharedPointer<FolderCollection> fd = FolderCollection::forCollection( parentCol, false );
      if ( fd )
        command = new KMForwardCommand( this, mReaderWin->message(),
                                        fd->identity() );
@@ -208,8 +217,9 @@ void KMReaderMainWin::slotForwardAttachedMsg()
 {
   if ( !mReaderWin->message().hasPayload<KMime::Message::Ptr>() ) return;
    KMCommand *command = 0;
-   if ( mReaderWin->message().isValid() && mReaderWin->message().parentCollection().isValid() ) {
-     QSharedPointer<FolderCollection> fd = FolderCollection::forCollection( mReaderWin->message().parentCollection(), false );
+   const Akonadi::Collection parentCol = mReaderWin->message().parentCollection();
+   if ( parentCol.isValid() ) {
+     QSharedPointer<FolderCollection> fd = FolderCollection::forCollection( parentCol, false );
      if ( fd )
        command = new KMForwardAttachedCommand( this, mReaderWin->message(),
                                                fd->identity() );
@@ -434,8 +444,8 @@ void KMReaderMainWin::slotDelayedMessagePopup( KJob *job )
       return;
     }
     bool replyForwardMenu = false;
-    if ( mMsg.parentCollection().isValid() ) {
-      Akonadi::Collection col = mMsg.parentCollection();
+    Akonadi::Collection col = parentCollection();
+    if ( col.isValid() ) {
       if ( ! ( CommonKernel->folderIsSentMailFolder( col ) ||
                CommonKernel->folderIsDrafts( col ) ||
                CommonKernel->folderIsTemplates( col ) ) ) {
