@@ -59,6 +59,7 @@ private slots:
   void slotContextMenuAboutToShow();
   void slotSelectCollection(QAction*act);
   void initListOfCollection();
+  void slotCollectionStatisticsChanged( Akonadi::Collection::Id,const Akonadi::CollectionStatistics& );
   
 protected:
   bool mainWindowIsOnCurrentDesktop();
@@ -66,6 +67,8 @@ protected:
   void updateCount();
   void fillFoldersMenu( QMenu *menu, const QAbstractItemModel *model, const QString& parentName = QString(), const QModelIndex& parentIndex = QModelIndex() );
   void unreadMail( const QAbstractItemModel *model, const QModelIndex& parentIndex = QModelIndex() );
+  
+  bool excludeFolder( const Akonadi::Collection& collection ) const;
 
 private:
 
