@@ -37,11 +37,7 @@
 
 #include <kcombobox.h>
 #include <klocale.h>
-#if KDE_IS_VERSION( 4, 5, 74 )
 #include <keditlistwidget.h>
-#else
-#include <keditlistbox.h>
-#endif
 #include <kdebug.h>
 #include <kmessagebox.h>
 #include <kmcommands.h>
@@ -49,6 +45,7 @@
 
 #include <akonadi/itemfetchjob.h>
 #include <akonadi/itemfetchscope.h>
+#include <akonadi/kmime/messageparts.h>
 
 using namespace KMail;
 using namespace MailCommon;
@@ -144,11 +141,7 @@ MailingListFolderPropertiesDialog::MailingListFolderPropertiesDialog( QWidget* p
   }
   groupLayout->addWidget( handleButton, 6, 2 );
 
-#if KDE_IS_VERSION( 4, 5, 74 )
   mEditList = new KEditListWidget( mlGroup );
-#else
-  mEditList = new KEditListBox( mlGroup );
-#endif
   mEditList->setEnabled( false );
   groupLayout->addWidget( mEditList, 7, 0, 1, 4 );
 
@@ -232,9 +225,10 @@ void MailingListFolderPropertiesDialog::slotDetectMailingList()
   if ( !( mMailingList.features() & MailingList::Post ) ) {
 
     Akonadi::ItemFetchJob *job = new Akonadi::ItemFetchJob( mFolder->collection(), this );
-    job->fetchScope().setAncestorRetrieval( Akonadi::ItemFetchScope::Parent );
-    job->fetchScope().fetchFullPayload();
-    connect( job, SIGNAL( result( KJob* ) ), this, SLOT( slotFetchDone( KJob* ) ) );
+    job->fetchScope().fetchPayloadPart( Akonadi::MessagePart::Header );
+    connect( job, SIGNAL(result(KJob*)), this, SLOT(slotFetchDone(KJob*)) );
+    //Don't allow to reactive it
+    mDetectButton->setEnabled( false );
   }
   else {
     mMLId->setText( (mMailingList.id().isEmpty() ? i18n("Not available.") : mMailingList.id() ) );
@@ -245,6 +239,7 @@ void MailingListFolderPropertiesDialog::slotDetectMailingList()
 
 void MailingListFolderPropertiesDialog::slotFetchDone( KJob* job )
 {
+  mDetectButton->setEnabled( true );
   if ( job->error() ) {
     // handle errors
     MailCommon::Util::showJobErrorMessage(job);
@@ -300,8 +295,8 @@ void MailingListFolderPropertiesDialog::fillMLFromWidgets()
   bool changed = false;
   QStringList oldList = mEditList->items();
   QStringList newList; // the correct string list
-  for ( QStringList::ConstIterator it = oldList.constBegin();
-        it != oldList.constEnd(); ++it ) {
+  QStringList::ConstIterator end = oldList.constEnd();
+  for ( QStringList::ConstIterator it = oldList.constBegin(); it != end; ++it ) {
     if ( !(*it).startsWith(QLatin1String("http:")) && !(*it).startsWith(QLatin1String("https:")) &&
          !(*it).startsWith(QLatin1String("mailto:")) && ( (*it).contains(QLatin1Char('@')) ) ) {
       changed = true;
