@@ -103,6 +103,10 @@ MessageActions::MessageActions( KActionCollection *ac, QWidget* parent ) :
            this, SLOT(slotNoQuoteReplyToMsg()) );
 
 
+  mListFilterAction = new KAction(i18n("Filter on Mailing-&List..."), this);
+  mActionCollection->addAction("mlist_filter", mListFilterAction );
+  connect(mListFilterAction, SIGNAL(triggered(bool)), SLOT(slotMailingListFilter()));
+  
   mCreateTodoAction = new KAction( KIcon( "task-new" ), i18n( "Create To-do/Reminder..." ), this );
   mCreateTodoAction->setIconText( i18n( "Create To-do" ) );
   mCreateTodoAction->setHelpText( i18n( "Allows you to create a calendar to-do or reminder from this message" ) );
@@ -279,17 +283,12 @@ void MessageActions::updateActions()
   mStatusMenu->setEnabled( multiVisible );
 
   if ( mCurrentItem.hasPayload<KMime::Message::Ptr>() ) {
-
-    if ( !mCurrentItem.loadedPayloadParts().contains( Akonadi::MessagePart::Header ) ) {
-      mMailingListActionMenu->setEnabled( false );
-      Akonadi::ItemFetchJob *job = new Akonadi::ItemFetchJob( mCurrentItem, this );
-      job->fetchScope().fetchPayloadPart( Akonadi::MessagePart::Header );
-      connect( job, SIGNAL(result(KJob*)), SLOT(slotUpdateActionsFetchDone(KJob*)) );
-    } else {
-      updateMailingListActions( mCurrentItem );
-    }
+    Akonadi::ItemFetchJob *job = new Akonadi::ItemFetchJob( mCurrentItem );
+    job->fetchScope().fetchAllAttributes();
+    job->fetchScope().fetchFullPayload( true );
+    job->fetchScope().fetchPayloadPart( Akonadi::MessagePart::Header );
+    connect( job, SIGNAL(result(KJob*)), SLOT(slotUpdateActionsFetchDone(KJob*)) );
   }
-
   mEditAction->setEnabled( singleMsg );
 }
 
@@ -311,10 +310,13 @@ void MessageActions::slotUpdateActionsFetchDone(KJob* job)
 
 void MessageActions::updateMailingListActions( const Akonadi::Item& messageItem )
 {
-  const MessageCore::MailingList mailList = MessageCore::MailingList::detect( MessageCore::Util::message( messageItem ) );
+  KMime::Message::Ptr message = messageItem.payload<KMime::Message::Ptr>();
+  const MessageCore::MailingList mailList = MessageCore::MailingList::detect( message );
 
   if ( mailList.features() == MessageCore::MailingList::None ) {
     mMailingListActionMenu->setEnabled( false );
+    mListFilterAction->setEnabled( false );
+    mListFilterAction->setText( i18n("Filter on Mailing-List...") );
   } else {
     // A mailing list menu with only a title is pretty boring
     // so make sure theres at least some content
@@ -355,6 +357,15 @@ void MessageActions::updateMailingListActions( const Akonadi::Item& messageItem
     if ( mailList.features() & MessageCore::MailingList::Unsubscribe )
       addMailingListActions( i18n( "Unsubscribe from List" ), mailList.unsubscribeUrls() );
     mMailingListActionMenu->setEnabled( true );
+
+    QByteArray name;
+    QString value;
+    const QString lname = MailingList::name( message, name, value );
+    if ( !lname.isEmpty() )
+    {
+      mListFilterAction->setEnabled( true );
+      mListFilterAction->setText( i18n( "Filter on Mailing-List %1...", lname ) );
+    }
   }
 }
 
@@ -460,30 +471,38 @@ void MessageActions::slotRunUrl( QAction *urlAction )
   }
 }
 
+void MessageActions::slotMailingListFilter()
+{
+  if ( !mCurrentItem.hasPayload<KMime::Message::Ptr>() )
+    return;
+  
+  KMCommand *command = new KMMailingListFilterCommand( mParent, mCurrentItem );
+  command->start();
+}
+
+
 void MessageActions::slotPrintMsg()
 {
-  const bool htmlOverride = mMessageView ? mMessageView->htmlOverride() : false;
-  const bool htmlLoadExtOverride = mMessageView ? mMessageView->htmlLoadExtOverride() : false;
-  const bool useFixedFont = mMessageView ? mMessageView->isFixedFont() :
-                                           MessageViewer::GlobalSettings::self()->useFixedFont();
-  const QString overrideEncoding = mMessageView ? mMessageView->overrideEncoding() :
-                                 MessageCore::GlobalSettings::self()->overrideCharacterEncoding();
+  if ( mMessageView )
+  {
+    mMessageView->viewer()->print();
+  }
+  else
+  {
+    const bool htmlOverride = false;
+    const bool htmlLoadExtOverride = false;
+    const bool useFixedFont = MessageViewer::GlobalSettings::self()->useFixedFont();
+    const QString overrideEncoding = MessageCore::GlobalSettings::self()->overrideCharacterEncoding();
 
-  // FIXME: This is broken when the Viewer shows an encapsulated message
-  const Akonadi::Item message = mMessageView ? mMessageView->message() : mCurrentItem;
-  KMPrintCommand *command =
-    new KMPrintCommand( mParent, message,
-                        mMessageView ? mMessageView->headerStyle() : 0,
-                        mMessageView ? mMessageView->headerStrategy() : 0,
-                        htmlOverride, htmlLoadExtOverride,
-                        useFixedFont, overrideEncoding );
-
-  if ( mMessageView ) {
-    command->setAttachmentStrategy( mMessageView->attachmentStrategy() );
-    command->setOverrideFont( mMessageView->cssHelper()->bodyFont(
-        mMessageView->isFixedFont(), true /*printing*/ ) );
+    const Akonadi::Item message = mCurrentItem;
+    KMPrintCommand *command =
+      new KMPrintCommand( mParent, message,
+                          0,
+                          0,
+                          htmlOverride, htmlLoadExtOverride,
+                          useFixedFont, overrideEncoding );
+    command->start();
   }
-  command->start();
 }
 
 
