@@ -32,6 +32,8 @@
 #include "searchdescriptionattribute.h"
 #include "foldertreeview.h"
 #include "kmsearchmessagemodel.h"
+#include "kmsearchfilterproxymodel.h"
+
 #include <Akonadi/AttributeFactory>
 #include <Akonadi/CollectionModifyJob>
 #include <Akonadi/CollectionStatisticsJob>
@@ -43,7 +45,6 @@
 #include <akonadi/standardactionmanager.h>
 #include <Akonadi/EntityMimeTypeFilterModel>
 #include <KActionMenu>
-#include <KConfigGroup>
 #include <KDebug>
 #include <KIcon>
 #include <KIconLoader>
@@ -76,8 +77,6 @@ using namespace MailCommon;
 
 namespace KMail {
 
-const int SearchWindow::MSGID_COLUMN = 4;
-
 SearchWindow::SearchWindow( KMMainWidget *widget, const Akonadi::Collection &collection )
   : KDialog( 0 ),
     mStopped( false ),
@@ -385,10 +384,8 @@ void SearchWindow::createSearchModel()
 {
   mResultModel = new KMSearchMessageModel( this );
   mResultModel->setCollection( mFolder );
-  QSortFilterProxyModel *sortproxy = new QSortFilterProxyModel( this );
+  KMSearchFilterProxyModel *sortproxy = new KMSearchFilterProxyModel( this );
   sortproxy->setSourceModel( mResultModel );
-  sortproxy->setDynamicSortFilter( true );
-  sortproxy->setFilterCaseSensitivity ( Qt::CaseInsensitive );
   mLbxMatches->setModel( sortproxy );
 
   mLbxMatches->setColumnWidth( 0, GlobalSettings::self()->collectionWidth() );
