@@ -47,7 +47,7 @@
 #include <QHeaderView>
 #include <QItemSelectionModel>
 
-#include <akonadi_next/kcheckableproxymodel.h>
+#include <kcheckableproxymodel.h>
 
 #include <akonadi/calendar/standardcalendaractionmanager.h>
 #include <akonadi/collection.h>
@@ -71,8 +71,6 @@
 #include <QStyledItemDelegate>
 #include <QPainter>
 
-using namespace Future;
-
 AkonadiCollectionViewFactory::AkonadiCollectionViewFactory( CalendarView *view )
   : mView( view ), mAkonadiCollectionView( 0 )
 {
@@ -220,7 +218,7 @@ AkonadiCollectionView::AkonadiCollectionView( CalendarView* view, bool hasContex
   collectionproxymodel->setObjectName( "Only show collections" );
   collectionproxymodel->setDynamicSortFilter( true );
   collectionproxymodel->addMimeTypeFilter( QString::fromLatin1( "text/calendar" ) );
-  //collectionproxymodel->addExcludedSpecialResources(Akonadi::Collection::SearchResource);
+  collectionproxymodel->setExcludeVirtualCollections( true );
 
   ColorProxyModel* colorProxy = new ColorProxyModel( this );
   colorProxy->setObjectName( "Show calendar colors" );
@@ -241,6 +239,9 @@ AkonadiCollectionView::AkonadiCollectionView( CalendarView* view, bool hasContex
   filterTreeViewModel->setFilterCaseSensitivity( Qt::CaseInsensitive );
   filterTreeViewModel->setObjectName( "Recursive filtering, for the search bar" );
   mCollectionview->setModel( filterTreeViewModel );
+  connect( mCollectionview->selectionModel(),
+           SIGNAL(selectionChanged(QItemSelection,QItemSelection)),
+           SLOT(updateMenu()) );
 
   //connect( searchCol, SIGNAL( textChanged(QString) ), filterTreeViewModel, SLOT( setFilterFixedString(QString) ) );
 
@@ -355,7 +356,10 @@ void AkonadiCollectionView::setCollectionSelectionProxyModel( KCheckableProxyMod
   if ( !mSelectionProxyModel )
     return;
   mBaseModel->setSourceModel( mSelectionProxyModel );
-  connect( mSelectionProxyModel->selectionModel(), SIGNAL(selectionChanged(QItemSelection,QItemSelection)), this, SLOT(selectionChanged()) );
+
+  connect( mSelectionProxyModel->selectionModel(),
+           SIGNAL(selectionChanged(QItemSelection,QItemSelection)),
+           SLOT(updateView()) );
 }
 
 KCheckableProxyModel *AkonadiCollectionView::collectionSelectionProxyModel() const
@@ -410,12 +414,6 @@ void AkonadiCollectionView::updateMenu()
   }
 }
 
-void AkonadiCollectionView::selectionChanged()
-{
-  updateMenu();
-  updateView();
-}
-
 void AkonadiCollectionView::newCalendar()
 {
   Akonadi::AgentTypeDialog dlg( this );
