@@ -40,6 +40,8 @@
 #include "kotodoviewsortfilterproxymodel.h"
 #include "kotodoviewview.h"
 
+#include <calendarviews/eventviews/eventview.h>
+#include <calendarsupport/collectionselection.h>
 #include <calendarsupport/kcalprefs.h>
 #include <calendarsupport/categoryconfig.h>
 #include <calendarsupport/utils.h>
@@ -60,25 +62,33 @@
 using namespace KPIM;
 using namespace CalendarSupport;
 
-KOTodoView::KOTodoView( QWidget *parent )
+// Share the model with the sidepanel KOTodoView
+K_GLOBAL_STATIC( KOTodoModel, sModel );
+
+KOTodoView::KOTodoView( bool sidebarView, QWidget *parent )
   : BaseView( parent )
 {
-  mModel = new KOTodoModel( this );
-  connect( mModel, SIGNAL( expandIndex( const QModelIndex& ) ),
+  connect( sModel, SIGNAL( expandIndex( const QModelIndex& ) ),
            this, SLOT( expandIndex( const QModelIndex& ) ) );
   mProxyModel = new KOTodoViewSortFilterProxyModel( this );
-  mProxyModel->setSourceModel( mModel );
+  mProxyModel->setSourceModel( sModel );
   mProxyModel->setDynamicSortFilter( true );
   mProxyModel->setFilterKeyColumn( KOTodoModel::SummaryColumn );
   mProxyModel->setFilterCaseSensitivity( Qt::CaseInsensitive );
   mProxyModel->setSortRole( Qt::EditRole );
 
-  mQuickSearch = new KOTodoViewQuickSearch( calendar(), this );
-  mQuickSearch->setVisible( KOPrefs::instance()->enableTodoQuickSearch() );
-  connect( mQuickSearch, SIGNAL(searchTextChanged(const QString &)),
-           mProxyModel, SLOT(setFilterRegExp(const QString &)) );
-  connect( mQuickSearch, SIGNAL(searchCategoryChanged(const QStringList &)),
-           mProxyModel, SLOT(setCategoryFilter(const QStringList &)) );
+  // This disconnect is a workaround against QTBUG-22667
+  disconnect( sModel, SIGNAL(destroyed()), mProxyModel, 0  );
+
+  mSidebarView = sidebarView;
+  if ( !mSidebarView ) {
+    mQuickSearch = new KOTodoViewQuickSearch( calendar(), this );
+    mQuickSearch->setVisible( KOPrefs::instance()->enableTodoQuickSearch() );
+    connect( mQuickSearch, SIGNAL(searchTextChanged(const QString &)),
+             mProxyModel, SLOT(setFilterRegExp(const QString &)) );
+    connect( mQuickSearch, SIGNAL(searchCategoryChanged(const QStringList &)),
+             mProxyModel, SLOT(setCategoryFilter(const QStringList &)) );
+  }
 
   mView = new KOTodoViewView( this );
   mView->setModel( mProxyModel );
@@ -136,15 +146,26 @@ KOTodoView::KOTodoView( QWidget *parent )
            "flat list instead of a hierarchical tree; the parental "
            "relationships are removed in the display." ) );
   connect( mFlatView, SIGNAL(toggled(bool)),
-           this, SLOT(setFlatView(bool)) );
+           sModel, SLOT(setFlatView(bool)) );
+  connect( sModel,SIGNAL(flatViewChanged(bool)),
+           SLOT(setFlatView(bool)) );
 
   QGridLayout *layout = new QGridLayout( this );
   layout->setMargin( 0 );
-  layout->addWidget( mQuickSearch, 0, 0, 1, 2 );
+  if ( !mSidebarView ) {
+    layout->addWidget( mQuickSearch, 0, 0, 1, 2 );
+  }
   layout->addWidget( mView, 1, 0, 1, 2 );
   layout->setRowStretch( 1, 1 );
   layout->addWidget( mQuickAdd, 2, 0 );
-  layout->addWidget( mFlatView, 2, 1 );
+
+  // Dummy layout just to add a few px of right margin so the checkbox is aligned
+  // with the QAbstractItemView's viewport.
+  QHBoxLayout *dummyLayout = new QHBoxLayout();
+  dummyLayout->setContentsMargins( 0, 0, mView->frameWidth()/*right*/, 0 );
+  dummyLayout->addWidget( mFlatView );
+
+  layout->addLayout( dummyLayout, 2, 1 );
 
   setLayout( layout );
 
@@ -275,9 +296,11 @@ void KOTodoView::expandIndex( const QModelIndex &index )
 void KOTodoView::setCalendar( CalendarSupport::Calendar *cal )
 {
   BaseView::setCalendar( cal );
-  mQuickSearch->setCalendar( cal );
+  if ( !mSidebarView ) {
+    mQuickSearch->setCalendar( cal );
+  }
   mCategoriesDelegate->setCalendar( cal );
-  mModel->setCalendar( cal );
+  sModel->setCalendar( cal );
 }
 
 Akonadi::Item::List KOTodoView::selectedIncidences()
@@ -379,10 +402,10 @@ void KOTodoView::restoreLayout( KConfig *config, const QString &group, bool mini
 void KOTodoView::setIncidenceChanger( CalendarSupport::IncidenceChanger *changer )
 {
   BaseView::setIncidenceChanger( changer );
-  mModel->setIncidenceChanger( changer );
+  sModel->setIncidenceChanger( changer );
 }
 
-void KOTodoView::showDates( const QDate &start, const QDate &end )
+void KOTodoView::showDates( const QDate &start, const QDate &end, const QDate & )
 {
   // There is nothing to do here for the Todo View
   Q_UNUSED( start );
@@ -397,23 +420,25 @@ void KOTodoView::showIncidences( const Akonadi::Item::List &incidenceList, const
 
 void KOTodoView::updateView()
 {
-  mModel->reloadTodos();
+  sModel->reloadTodos();
 }
 
 void KOTodoView::updateCategories()
 {
-  mQuickSearch->updateCategories();
+  if ( !mSidebarView )
+    mQuickSearch->updateCategories();
   // TODO check if we have to do something with the category delegate
 }
 
 void KOTodoView::changeIncidenceDisplay( const Akonadi::Item &incidence, int action )
 {
-  mModel->processChange( incidence, action );
+  sModel->processChange( incidence, action );
 }
 
 void KOTodoView::updateConfig()
 {
-  mQuickSearch->setVisible( KOPrefs::instance()->enableTodoQuickSearch() );
+  if ( !mSidebarView )
+    mQuickSearch->setVisible( KOPrefs::instance()->enableTodoQuickSearch() );
   mQuickAdd->setVisible( KOPrefs::instance()->enableQuickTodo() );
 
   updateView();
@@ -439,18 +464,33 @@ void KOTodoView::addTodo( const QString &summary,
 
   todo->setCategories( categories );
 
-/*  if ( parent ) {
+  /*  if ( parent ) {
     todo->setRelatedTo( parent );
   }
-KDAB_TODO: review
-*/
+  TODO: review
+  */
 
-  Akonadi::Collection selectedCollection;
-  int dialogCode = 0;
-  if ( !mChanger->addIncidence( todo, this, selectedCollection, dialogCode ) ) {
-    if ( dialogCode != QDialog::Rejected ) {
-      KOHelper::showSaveIncidenceErrorMsg( this, todo );
+  bool result = false;
+  CalendarSupport::CollectionSelection *selection = EventViews::EventView::globalCollectionSelection();
+
+  // If we only have one collection, don't ask in which collection to save the to-do.
+  if ( selection && selection->model()->model()->rowCount() == 1 ) {
+    QModelIndex index = selection->model()->model()->index( 0, 0 );
+    if ( index.isValid() ) {
+      Akonadi::Collection collection = CalendarSupport::collectionFromIndex( index );
+      if ( collection.isValid() ) {
+        result = mChanger->addIncidence( todo, collection, this );
+      }
     }
+  } else {
+    Akonadi::Collection selectedCollection;
+    int dialogCode = 0;
+    result = mChanger->addIncidence( todo, this, selectedCollection, dialogCode );
+    result = result || dialogCode == QDialog::Rejected;
+  }
+
+  if ( !result ) {
+    KOHelper::showSaveIncidenceErrorMsg( this, todo );
   }
 }
 
@@ -478,7 +518,7 @@ void KOTodoView::addQuickTodo( Qt::KeyboardModifiers modifiers )
       return;
     }
     const QModelIndex idx = mProxyModel->mapToSource( selection[0] );
-    const Akonadi::Item parent = mModel->todoForIndex( idx );
+    const Akonadi::Item parent = sModel->todoForIndex( idx );
     addTodo( mQuickAdd->text(), CalendarSupport::todo( parent ), mProxyModel->categories() );
   } else {
     return;
@@ -677,7 +717,7 @@ void KOTodoView::copyTodoToDate( const QDate &date )
   const QModelIndex origIndex = mProxyModel->mapToSource( selection[0] );
   Q_ASSERT( origIndex.isValid() );
 
-  const Akonadi::Item origItem = mModel->todoForIndex( origIndex );
+  const Akonadi::Item origItem = sModel->todoForIndex( origIndex );
   const Todo::Ptr orig = CalendarSupport::todo( origItem );
   if ( !orig ) {
     return;
@@ -856,8 +896,12 @@ void KOTodoView::changedCategories( QAction *action )
 
 void KOTodoView::setFlatView( bool flatView )
 {
+  mFlatView->blockSignals( true );
+  // We block signals to avoid recursion, we have two KOTodoViews and mFlatView is synchronized
+  mFlatView->setChecked( flatView );
+  mFlatView->blockSignals( false );
+
   mView->setRootIsDecorated( !flatView );
-  mModel->setFlatView( flatView );
 
   if ( flatView ) {
     // In flatview dropping confuses users and it's very easy to drop into a child item
