@@ -22,6 +22,8 @@
  */
 
 #include "ldapclient.h"
+#include "ldapsession.h"
+#include "ldapqueryjob.h"
 
 #include <kldap/ldapobject.h>
 #include <kldap/ldapserver.h>
@@ -50,13 +52,18 @@ class LdapClient::Private
     Private( LdapClient *qq )
       : q( qq ),
         mJob( 0 ),
-        mActive( false )
+        mActive( false ),
+        mSession( 0 )
     {
     }
 
     ~Private()
     {
       q->cancelQuery();
+#ifdef KDEPIM_INPROCESS_LDAP
+      mSession->disconnectAndDelete();
+      mSession = 0;
+#endif
     }
 
     void startParseLDIF();
@@ -65,6 +72,7 @@ class LdapClient::Private
     void finishCurrentObject();
 
     void slotData( KIO::Job*, const QByteArray &data );
+    void slotData( const QByteArray &data );
     void slotInfoMessage( KJob*, const QString &info, const QString& );
     void slotDone();
 
@@ -74,13 +82,15 @@ class LdapClient::Private
     QString mScope;
     QStringList mAttrs;
 
-    QPointer<KIO::TransferJob> mJob;
+    QPointer<KJob> mJob;
     bool mActive;
 
     KLDAP::LdapObject mCurrentObject;
     KLDAP::Ldif mLdif;
     int mClientNumber;
     int mCompletionWeight;
+
+    KLDAP::LdapSession *mSession;
 };
 
 LdapClient::LdapClient( int clientNumber, QObject *parent )
@@ -103,6 +113,11 @@ bool LdapClient::isActive() const
 void LdapClient::setServer( const KLDAP::LdapServer &server )
 {
   d->mServer = server;
+#ifdef KDEPIM_INPROCESS_LDAP
+  if ( !d->mSession )
+    d->mSession = new LdapSession( this );
+  d->mSession->connectToServer( server );
+#endif
 }
 
 const KLDAP::LdapServer LdapClient::server() const
@@ -141,9 +156,17 @@ void LdapClient::startQuery( const QString &filter )
 
   d->startParseLDIF();
   d->mActive = true;
+#ifndef KDEPIM_INPROCESS_LDAP
   d->mJob = KIO::get( url, KIO::NoReload, KIO::HideProgressInfo );
   connect( d->mJob, SIGNAL( data( KIO::Job*, const QByteArray& ) ),
            this, SLOT( slotData( KIO::Job*, const QByteArray& ) ) );
+#else
+  if ( !d->mSession )
+    return;
+  d->mJob = d->mSession->get( url );
+  connect( d->mJob, SIGNAL( data( const QByteArray& ) ),
+           this, SLOT( slotData( const QByteArray& ) ) );
+#endif
   connect( d->mJob, SIGNAL( infoMessage( KJob*, const QString&, const QString& ) ),
            this, SLOT( slotInfoMessage( KJob*, const QString&, const QString& ) ) );
   connect( d->mJob, SIGNAL( result( KJob* ) ),
@@ -165,6 +188,11 @@ void LdapClient::Private::slotData( KIO::Job*, const QByteArray &data )
   parseLDIF( data );
 }
 
+void LdapClient::Private::slotData( const QByteArray &data )
+{
+  parseLDIF( data );
+}
+
 void LdapClient::Private::slotInfoMessage( KJob*, const QString&, const QString& )
 {
   //qDebug("Job said \"%s\"", info.toLatin1());
@@ -174,10 +202,15 @@ void LdapClient::Private::slotDone()
 {
   endParseLDIF();
   mActive = false;
+  if ( !mJob )
+    return;
   int err = mJob->error();
   if ( err && err != KIO::ERR_USER_CANCELED ) {
     emit q->error( mJob->errorString() );
   }
+#ifdef KDEPIM_INPROCESS_LDAP
+  QMetaObject::invokeMethod( mJob, "deleteLater", Qt::QueuedConnection ); // it's in a different thread
+#endif
   emit q->done();
 }
 
@@ -439,10 +472,13 @@ class LdapClientSearch::Private
 LdapClientSearch::LdapClientSearch( QObject *parent )
   : QObject( parent ), d( new Private( this ) )
 {
+#ifndef Q_OS_WINCE
+// There is no KSycoca on WinCE so this would always fail
   if ( !KProtocolInfo::isKnownProtocol( KUrl( "ldap://localhost" ) ) ) {
     d->mNoLDAPLookup = true;
     return;
   }
+#endif
 
   d->readConfig();
   connect( KDirWatch::self(), SIGNAL( dirty( const QString& ) ), this,
