@@ -124,7 +124,7 @@ void FilterAction::sendMDN( const Akonadi::Item &item, KMime::MDN::DispositionTy
   if ( !msg )
     return;
 
-  const QPair<bool, KMime::MDN::SendingMode> mdnSend = MDNAdviceHelper::instance()->checkAndSetMDNInfo( item, type );
+  const QPair<bool, KMime::MDN::SendingMode> mdnSend = MDNAdviceHelper::instance()->checkAndSetMDNInfo( item, type, true );
   if ( mdnSend.first ) {
     const int quote =  MessageViewer::GlobalSettings::self()->quoteMessage();
     MessageFactory factory( msg, Akonadi::Item().id() );
@@ -591,8 +591,10 @@ FilterAction::ReturnCode FilterActionWithCommand::genericProcess( const Akonadi:
   // KProcess doesn't support a QProcess::launch() equivalent, so
   // we must use a temp file :-(
   KTemporaryFile * inFile = new KTemporaryFile;
-  if ( !inFile->open() )
+  if ( !inFile->open() ) {
+    delete inFile;
     return ErrorButGoOn;
+  }
 
   QList<KTemporaryFile*> atmList;
   atmList.append( inFile );
