@@ -52,7 +52,7 @@ public:
   Akonadi::Collection collection() const;
 
 
-  QString configGroupName() const;
+  static QString configGroupName(const Akonadi::Collection& col);
 
 
   bool isWriteConfig() const;
@@ -204,12 +204,10 @@ public:
 
   QString mailingListPostAddress() const;
 
-  void removeCollection();
   void expireOldMessages( bool immediate );
 
 protected slots:
   void slotIdentitiesChanged();
-  void slotDeletionCollectionResult( KJob *job );
 
 signals:
   void viewConfigChanged();
