@@ -79,7 +79,7 @@ namespace Util {
 
     MAILCOMMON_EXPORT void showJobErrorMessage( KJob *job );
 
-    MAILCOMMON_EXPORT Akonadi::AgentInstance::List agentInstances();
+    MAILCOMMON_EXPORT Akonadi::AgentInstance::List agentInstances( bool excludeMailTransport = true);
     MAILCOMMON_EXPORT void ensureKorganizerRunning( bool switchTo );
     MAILCOMMON_EXPORT bool createTodoFromMail( const Akonadi::Item &mailItem );
     MAILCOMMON_EXPORT bool createEventFromMail( const Akonadi::Item &mailItem );
@@ -108,6 +108,9 @@ namespace Util {
      */
     MAILCOMMON_EXPORT QModelIndex nextUnreadCollection( QAbstractItemModel *model, const QModelIndex &current, SearchDirection direction,
                                                         bool (*ignoreCollectionCallback)( const Akonadi::Collection &collection ) = 0 );
+
+    MAILCOMMON_EXPORT Akonadi::Collection parentCollectionFromItem(const Akonadi::Item& item);
+
 }
 
 }
