@@ -221,7 +221,7 @@ void ComposerLineEdit::editRecentAddresses()
   if ( dlg->exec() && dlg ) {
     KPIM::RecentAddresses::self( m_recentAddressConfig )->clear();
     const QStringList addrList = dlg->addresses();
-    for ( QStringList::const_iterator it = addrList.begin(), end = addrList.end() ; it != end ; ++it )
+    for ( QStringList::const_iterator it = addrList.constBegin(), end = addrList.constEnd() ; it != end ; ++it )
       KPIM::RecentAddresses::self( MessageComposerSettings::self()->config() )->add( *it );
     loadContacts();
   }
