@@ -39,7 +39,7 @@
 #define MAILVIEWERUTIL_H
 
 #include "messageviewer_export.h"
-
+#include "kmime/kmime_content.h"
 #include <QString>
 
 class KUrl;
@@ -51,6 +51,10 @@ namespace KMime {
   class Message;
 }
 
+namespace Akonadi {
+  class Item;
+}
+
 namespace MessageViewer {
 
 /**
@@ -113,6 +117,9 @@ namespace Util {
     QString MESSAGEVIEWER_EXPORT fileNameForMimetype( const QString &mimeType, int iconSize,
                                  const QString &fallbackFileName1 = QString(),
                                  const QString &fallbackFileName2 = QString() );
+    bool MESSAGEVIEWER_EXPORT saveMessageInMbox( const QList<Akonadi::Item>& retrievedMsgs, QWidget*parent);
+
+    bool MESSAGEVIEWER_EXPORT saveAttachments( const KMime::Content::List& contents, QWidget *parent ); 
 
 }
 
